# Parallel build with too many cores brings up issues with luajit
%global _smp_ncpus_max 4

%define engine  t-engine

%ifarch aarch64
%bcond_with luajit2
%else
%bcond_without luajit2
%endif

Name:           t-engine4
Version:        1.7.2
Release:        %mkrel 2
Summary:        T-Engine4 is a graphical roguelike and tactical RPG engine
Group:          Games/Adventure
License:        GPLv3+
URL:            https://te4.org
# Tarball stripped of the files provided in the "tome" SRPM (part of it being nonfree)
Source0:        %{name}-%{version}.tar.xz
# Use this script to split the tarballs automatically
Source10:       split-tarballs.sh
Patch0:         t-engine4-1.3.1-mga-include-sdl2.patch
Patch1:         t-engine4-1.4.1-mga-no-stripping.patch

BuildRequires:  premake
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  zip
Recommends:     tome
Provides:       te4 = %{version}-%{release}

%description
T-Engine4 (TE4 for short) is a roguelike game engine operating in Lua and
available for all major platforms. It was primarily developed as the engine
for the Tales of Maj'Eyal game (see package "tome"), but other
games and mods are based on T-Engine4. See te4.org for more information.

%prep
%autosetup -p1

%build
premake4 --lua=%{!?with_luajit2:default}%{?with_luajit2:jit2} gmake
# Parallel build not supported https://github.com/premake/premake-core/issues/286
echo '.NOTPARALLEL:' >> build/buildvm.make
echo '.NOTPARALLEL:' >> build/luajit2.make
%make_build config=release CC=gcc CXX=g++

%install
# Generate and install the launcher script.
cat << EOF > %{engine}-script
#!/bin/sh
pushd %{_gamesdatadir}/%{name}
./%{engine}
popd
EOF

# Install the engine executable, launcher script.
# Since the executable searches for the data in its directory, I put it in the datadir (Akien)
install -D -m755 %{engine} %{buildroot}%{_gamesdatadir}/%{name}/%{engine}
install -D -m755 %{engine}-script %{buildroot}%{_gamesbindir}/%{engine}

# Install the common game data.
install -d %{buildroot}%{_gamesdatadir}/%{name}
cp -r bootstrap game %{buildroot}%{_gamesdatadir}/%{name}/

# Extract and install the icon. (AUR)
unzip -oj -qq game/engines/te4-%{version}.teae \
              data/gfx/te4-icon.png -d .
install -D -m644 te4-icon.png %{buildroot}%{_iconsdir}/hicolor/64x64/apps/%{name}.png

%files
%doc CONTRIBUTING COPYING-MEDIA CREDITS
%{_gamesbindir}/%{engine}
%{_gamesdatadir}/%{name}/
%{_iconsdir}/hicolor/64x64/apps/%{name}.png


%changelog
* Fri Apr 01 2022 umeabot <umeabot> 1.7.2-2.mga9
+ Revision: 1839235
- Mageia 9 Mass Rebuild

* Wed Dec 30 2020 akien <akien> 1.7.2-1.mga8
+ Revision: 1665766
- Version 1.7.2

* Fri Feb 14 2020 umeabot <umeabot> 1.5.10-3.mga8
+ Revision: 1522598
- Mageia 8 Mass Rebuild

* Mon Jan 28 2019 daviddavid <daviddavid> 1.5.10-2.mga7
+ Revision: 1361654
- add patch to fix conflicting glext.h

* Wed Oct 03 2018 wally <wally> 1.5.10-1.mga7
+ Revision: 1317251
- new version 1.5.10
- build with architecture agnostic lua on aarch64

* Sun Sep 23 2018 umeabot <umeabot> 1.5.5-2.mga7
+ Revision: 1301383
- Mageia 7 Mass Rebuild

* Thu May 25 2017 akien <akien> 1.5.5-1.mga6
+ Revision: 1104608
- Version 1.5.5

* Wed Apr 26 2017 akien <akien> 1.5.3-1.mga6
+ Revision: 1097701
- Version 1.5.3

* Fri Mar 17 2017 akien <akien> 1.5.1-1.mga6
+ Revision: 1093384
- Version 1.5.1

* Fri Mar 10 2017 akien <akien> 1.5.0-1.mga6
+ Revision: 1091556
- Version 1.5.0

* Sat Oct 29 2016 akien <akien> 1.4.9-1.mga6
+ Revision: 1063947
- Version 1.4.9

* Thu Oct 13 2016 pterjan <pterjan> 1.4.8-2.mga6
+ Revision: 1060657
- Disable parallel build

* Sat Jun 25 2016 akien <akien> 1.4.8-1.mga6
+ Revision: 1037591
- Version 1.4.8

* Sun Apr 17 2016 akien <akien> 1.4.6-1.mga6
+ Revision: 1003147
- Version 1.4.6

* Mon Apr 11 2016 daviddavid <daviddavid> 1.4.1-2.mga6
+ Revision: 1000493
- limit parallel build to level 4 (fails always on autobuild)

* Wed Jan 27 2016 akien <akien> 1.4.1-1.mga6
+ Revision: 928205
- Version 1.4.1
- Prevent stripping debuginfo

* Thu Apr 23 2015 akien <akien> 1.3.1-1.mga5
+ Revision: 820584
- Version 1.3.1
- Split package of "tome" game in a distinct "tome" SRPM
- Repack the tarball to remove the "tome"-specific content (partly nonfree)
- Drop custom patches that prevent online account usage due to non-pristine engine and game zipfiles

* Mon Jan 12 2015 akien <akien> 1.2.5-1.mga5
+ Revision: 810018
- Version 1.2.5
- Add AUR patch to unbundle Vera and Droid fonts using fontconfig
- Install icon to hicolor theme

* Wed Oct 29 2014 akien <akien> 1.2.4-1.mga5
+ Revision: 794609
- Version 1.2.4

* Wed Oct 15 2014 umeabot <umeabot> 1.2.3-2.mga5
+ Revision: 745662
- Second Mageia 5 Mass Rebuild

* Sun Sep 28 2014 akien <akien> 1.2.3-1.mga5.nonfree
+ Revision: 731036
- Version 1.2.3

* Tue Sep 16 2014 umeabot <umeabot> 1.2.2-2.mga5
+ Revision: 689671
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Tue Jun 24 2014 akien <akien> 1.2.2-1.mga5
+ Revision: 639160
- Bugfix version 1.2.2

* Wed Jun 04 2014 akien <akien> 1.2.0-1.mga5.nonfree
+ Revision: 632708
- New version 1.2.0: http://te4.org/blogs/darkgod/2014/05/news/tales-majeyal-120-aka-exercise-vital-powers-released
- Patch a lua script to open URLs using xdg-open
- Add reworked cursor gfx to workaround a transparency issue
- Move the tome package to nonfree, since part of the artwork is under a restrictive license
- t-engine4 provides te4

* Mon Mar 10 2014 akien <akien> 1.1.5-1.mga5
+ Revision: 601818
- New version 1.1.5
- Rename t-engine4-tome4 package to tome, the redundancy is not needed

* Mon Dec 23 2013 stormi <stormi> 1.1.0-1.mga4
+ Revision: 560049
- fix desktop file again
- fix desktop file
- add missing buildrequires: pkgconfig(glu)
+ akien <akien>
- Adding missing BR on zip and libvorbis-devel
- Limiting the parallel build to 4 cores only to prevent a build failure
- Update from upstream release 1.0.4 to 1.1.0
- Changelist for 1.0.5: http://te4.org/blogs/darkgod/2013/11/news/tales-majeyal-105-aka-mental-anything-released
- Changelist for 1.1.0: http://te4.org/blogs/darkgod/2013/12/news/tales-majeyal-110-aka-full-steam-ahead-released
- Adding descriptions
- imported package t-engine4

